You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2020/03/05 19:39:12 UTC

[camel] branch master updated: CAMEL-14645: Fixed compilation in elytron

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/master by this push:
     new 1580911  CAMEL-14645: Fixed compilation in elytron
1580911 is described below

commit 158091148041afd03a5280a6baecf744a08aef03
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu Mar 5 20:38:50 2020 +0100

    CAMEL-14645: Fixed compilation in elytron
---
 .../java/org/apache/camel/component/elytron/ElytronComponent.java  | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/components/camel-elytron/src/main/java/org/apache/camel/component/elytron/ElytronComponent.java b/components/camel-elytron/src/main/java/org/apache/camel/component/elytron/ElytronComponent.java
index 1a9d146..a62b61d 100644
--- a/components/camel-elytron/src/main/java/org/apache/camel/component/elytron/ElytronComponent.java
+++ b/components/camel-elytron/src/main/java/org/apache/camel/component/elytron/ElytronComponent.java
@@ -29,6 +29,7 @@ import io.undertow.server.HttpHandler;
 import org.apache.camel.CamelContext;
 import org.apache.camel.component.undertow.HttpHandlerRegistrationInfo;
 import org.apache.camel.component.undertow.UndertowComponent;
+import org.apache.camel.component.undertow.UndertowConsumer;
 import org.apache.camel.component.undertow.UndertowEndpoint;
 import org.apache.camel.spi.Metadata;
 import org.apache.camel.spi.annotations.Component;
@@ -48,7 +49,7 @@ import org.wildfly.security.http.util.FilterServerMechanismFactory;
 import org.wildfly.security.http.util.SecurityProviderServerMechanismFactory;
 
 /**
  * Elytron component brings elytron security over came-undertow component.
  *
  * Component work either as producer and as consumer.
  *
@@ -91,9 +92,9 @@ public class ElytronComponent extends UndertowComponent {
     }
 
     @Override
-    public HttpHandler registerEndpoint(HttpHandlerRegistrationInfo registrationInfo, SSLContext sslContext, HttpHandler handler) {
+    public HttpHandler registerEndpoint(UndertowConsumer consumer, HttpHandlerRegistrationInfo registrationInfo, SSLContext sslContext, HttpHandler handler) {
         //injecting elytron
-        return super.registerEndpoint(registrationInfo, sslContext, wrap(handler, getSecurityDomain()));
+        return super.registerEndpoint(consumer, registrationInfo, sslContext, wrap(handler, getSecurityDomain()));
     }
 
     /**
@@ -48,7 +49,7 @@ import org.wildfly.security.http.util.FilterServerMechanismFactory;
 
 /**
- * Elytron component brings elytron security over came-undertow component.
+ * Elytron component brings elytron security over camel-undertow component.
  *
  * Component work either as producer and as consumer.